AndroidSound class

A default Android sound, as used by FlutterRingtonePlayer.play.

Constructors

AndroidSound(int value)
Creates a sound from its type: 1 for alarm, 2 for notification and 3 for ringtone.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The sound type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited