IosSounds class abstract final

The built-in iOS sounds.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

alarm → const IosSound
The alarm sound.
bell → const IosSound
Bell.
chime → const IosSound
Chime.
electronic → const IosSound
Electronic.
glass → const IosSound
Glass.
horn → const IosSound
Horn.
lowPower → const IosSound
The "low power" sound.
mailSent → const IosSound
The "mail sent" sound.
newMail → const IosSound
The "new mail" sound.
receivedMessage → const IosSound
The "received message" sound.
sentMessage → const IosSound
The "sent message" sound.
triTone → const IosSound
Tri-tone.
voicemail → const IosSound
The voicemail sound. Not available on current iOS versions.