RingtonePlayerPlatform class abstract

The interface that platform implementations of this plugin extend.

Tests can replace instance with a fake to avoid calling native code.

Inheritance
  • Object
  • PlatformInterface
  • RingtonePlayerPlatform

Constructors

RingtonePlayerPlatform()
Constructs a platform implementation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateChanges → Stream<PlaybackState>
Playback events for sounds started through this interface.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play(RingtoneSource source, PlaybackOptions options) → Future<void>
Plays source with options, stopping the sound that is playing.
stop() → Future<void>
Stops the sound that is playing, if any.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ RingtonePlayerPlatform
The implementation in use, PigeonRingtonePlayer by default.
getter/setter pair