play abstract method
Plays source with options, stopping the sound that is playing.
Implementation
Future<void> play(RingtoneSource source, PlaybackOptions options);
Plays source with options, stopping the sound that is playing.
Future<void> play(RingtoneSource source, PlaybackOptions options);