IosSound class
A built-in iOS sound identified by its system sound ID, as used by FlutterRingtonePlayer.play.
Only the IDs listed in IosSounds are played. Other IDs, and IosSounds.voicemail, which no longer exists on current iOS versions, fall back to the default sound for the Android sound type of the call.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited